pub struct BufferBinding<'a> {
pub buffer: &'a Buffer,
pub offset: BufferAddress,
pub size: Option<BufferSize>,
}Expand description
Describes the segment of a buffer to bind.
Corresponds to WebGPU GPUBufferBinding.
Fields
buffer: &'a BufferThe buffer to bind.
offset: BufferAddressBase offset of the buffer, in bytes.
If the has_dynamic_offset field of this buffer’s layout entry is
true, the offset here will be added to the dynamic offset passed to
RenderPass::set_bind_group or ComputePass::set_bind_group.
If the buffer was created with BufferUsages::UNIFORM, then this
offset must be a multiple of
Limits::min_uniform_buffer_offset_alignment.
If the buffer was created with BufferUsages::STORAGE, then this
offset must be a multiple of
Limits::min_storage_buffer_offset_alignment.
size: Option<BufferSize>Size of the binding in bytes, or None for using the rest of the buffer.